==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QXmlStreamEntityDeclaration_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qxmlstream.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlStreamEntityDeclaration(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlStreamEntityDeclaration")
    QXmlStreamEntityDeclaration *_ptr = reinterpret_cast<QXmlStreamEntityDeclaration *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlStreamEntityDeclaration()
void __qt_construct_QXmlStreamEntityDeclaration(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamEntityDeclaration()")
    Q_UNUSED(__java_arguments)
    QXmlStreamEntityDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamEntityDeclaration();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_initialize_1native__Lio_qt_core_QXmlStreamEntityDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamEntityDeclaration, sizeof(QXmlStreamEntityDeclaration), typeid(QXmlStreamEntityDeclaration), false, &deleter_QXmlStreamEntityDeclaration, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QXmlStreamEntityDeclaration(QXmlStreamEntityDeclaration)
void __qt_construct_QXmlStreamEntityDeclaration_cref_QXmlStreamEntityDeclaration(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamEntityDeclaration(QXmlStreamEntityDeclaration)")
    jobject arg__1 = __java_arguments[0].l;
    const QXmlStreamEntityDeclaration& __qt_arg__1 = qtjambi_cast<const QXmlStreamEntityDeclaration& >(__jni_env, arg__1);
    QXmlStreamEntityDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamEntityDeclaration(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration(QXmlStreamEntityDeclaration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_initialize_1native__Lio_qt_core_QXmlStreamEntityDeclaration_2Lio_qt_core_QXmlStreamEntityDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration(QXmlStreamEntityDeclaration)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamEntityDeclaration_cref_QXmlStreamEntityDeclaration, sizeof(QXmlStreamEntityDeclaration), typeid(QXmlStreamEntityDeclaration), false, &deleter_QXmlStreamEntityDeclaration, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QXmlStreamEntityDeclaration
void __qt_destruct_QXmlStreamEntityDeclaration(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlStreamEntityDeclaration")
    reinterpret_cast<QXmlStreamEntityDeclaration*>(ptr)->~QXmlStreamEntityDeclaration();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlStreamEntityDeclaration::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::name()const", __qt_this)
        QStringRef __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamEntityDeclaration::notationName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_notationName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::notationName()const", __qt_this)
        QStringRef __qt_return_value = __qt_this->notationName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamEntityDeclaration::operator=(QXmlStreamEntityDeclaration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_assign_1native_1cref_1QXmlStreamEntityDeclaration__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::operator=(QXmlStreamEntityDeclaration)", __qt_this)
        const QXmlStreamEntityDeclaration& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QXmlStreamEntityDeclaration>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlStreamEntityDeclaration::operator==(QXmlStreamEntityDeclaration)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_equals_1native_1cref_1QXmlStreamEntityDeclaration_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::operator==(QXmlStreamEntityDeclaration)const", __qt_this)
        const QXmlStreamEntityDeclaration& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QXmlStreamEntityDeclaration>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamEntityDeclaration::publicId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_publicId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::publicId()const", __qt_this)
        QStringRef __qt_return_value = __qt_this->publicId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamEntityDeclaration::systemId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_systemId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::systemId()const", __qt_this)
        QStringRef __qt_return_value = __qt_this->systemId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamEntityDeclaration::value()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::value()const", __qt_this)
        QStringRef __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QXmlStreamEntityDeclaration(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QXmlStreamEntityDeclaration>("QXmlStreamEntityDeclaration", "io/qt/core/QXmlStreamEntityDeclaration");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QXmlStreamEntityDeclaration, {
        ConstructorInfo(&__qt_construct_QXmlStreamEntityDeclaration, nullptr)
       ,ConstructorInfo(&__qt_construct_QXmlStreamEntityDeclaration_cref_QXmlStreamEntityDeclaration, "Lio/qt/core/QXmlStreamEntityDeclaration;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlStreamEntityDeclaration);
    registerMetaType<QXmlStreamEntityDeclaration>("QXmlStreamEntityDeclaration");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QXmlStreamEntityDeclaration_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qxmlstream.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlStreamEntityDeclaration(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlStreamEntityDeclaration")
    QXmlStreamEntityDeclaration *_ptr = reinterpret_cast<QXmlStreamEntityDeclaration *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlStreamEntityDeclaration()
void __qt_construct_QXmlStreamEntityDeclaration(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamEntityDeclaration()")
    Q_UNUSED(__java_arguments)
    QXmlStreamEntityDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamEntityDeclaration();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_initialize_1native__Lio_qt_core_QXmlStreamEntityDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamEntityDeclaration, sizeof(QXmlStreamEntityDeclaration), typeid(QXmlStreamEntityDeclaration), 0, false, &deleter_QXmlStreamEntityDeclaration, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QXmlStreamEntityDeclaration(QXmlStreamEntityDeclaration)
void __qt_construct_QXmlStreamEntityDeclaration_cref_QXmlStreamEntityDeclaration(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamEntityDeclaration(QXmlStreamEntityDeclaration)")
    jobject other0 = __java_arguments[0].l;
    const QXmlStreamEntityDeclaration& __qt_other0 = qtjambi_cast<const QXmlStreamEntityDeclaration&>(__jni_env, other0);
    QXmlStreamEntityDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamEntityDeclaration(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration(QXmlStreamEntityDeclaration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_initialize_1native__Lio_qt_core_QXmlStreamEntityDeclaration_2Lio_qt_core_QXmlStreamEntityDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration(QXmlStreamEntityDeclaration)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamEntityDeclaration_cref_QXmlStreamEntityDeclaration, sizeof(QXmlStreamEntityDeclaration), typeid(QXmlStreamEntityDeclaration), 0, false, &deleter_QXmlStreamEntityDeclaration, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QXmlStreamEntityDeclaration
void __qt_destruct_QXmlStreamEntityDeclaration(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlStreamEntityDeclaration")
    reinterpret_cast<QXmlStreamEntityDeclaration*>(ptr)->~QXmlStreamEntityDeclaration();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlStreamEntityDeclaration::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::name()const", __this_nativeId)
        QStringView __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamEntityDeclaration::notationName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_notationName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::notationName()const", __this_nativeId)
        QStringView __qt_return_value = __qt_this->notationName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamEntityDeclaration::operator==(QXmlStreamEntityDeclaration)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_equals_1native_1cref_1QXmlStreamEntityDeclaration_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::operator==(QXmlStreamEntityDeclaration)const", __this_nativeId)
        const QXmlStreamEntityDeclaration& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QXmlStreamEntityDeclaration>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamEntityDeclaration::publicId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_publicId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::publicId()const", __this_nativeId)
        QStringView __qt_return_value = __qt_this->publicId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamEntityDeclaration::systemId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_systemId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::systemId()const", __this_nativeId)
        QStringView __qt_return_value = __qt_this->systemId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamEntityDeclaration::value()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamEntityDeclaration::value()const", __this_nativeId)
        QStringView __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamEntityDeclaration_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QXmlStreamEntityDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamEntityDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QXmlStreamEntityDeclaration(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QXmlStreamEntityDeclaration>("QXmlStreamEntityDeclaration", "io/qt/core/QXmlStreamEntityDeclaration");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QXmlStreamEntityDeclaration, {
        ConstructorInfo(&__qt_construct_QXmlStreamEntityDeclaration, nullptr)
       ,ConstructorInfo(&__qt_construct_QXmlStreamEntityDeclaration_cref_QXmlStreamEntityDeclaration, "Lio/qt/core/QXmlStreamEntityDeclaration;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlStreamEntityDeclaration);
    registerMetaType<QXmlStreamEntityDeclaration>("QXmlStreamEntityDeclaration");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
